summaryrefslogtreecommitdiff
path: root/framework/source/jobs
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2018-01-14 12:42:46 +0100
committerJulien Nabet <serval2412@yahoo.fr>2018-01-14 16:31:26 +0100
commita452643b431803b613919871abf1a81de6de3464 (patch)
tree742b35a02a320f584357b80eb956ea0c94a03e7a /framework/source/jobs
parentcfffb09b3d6d46c500e3be3fe601a4ff6944d40e (diff)
Fix typos
Change-Id: I2b4988e1d81fe60f7699362480cd739d2620c053 Reviewed-on: https://gerrit.libreoffice.org/47856 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Julien Nabet <serval2412@yahoo.fr>
Diffstat (limited to 'framework/source/jobs')
-rw-r--r--framework/source/jobs/job.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/framework/source/jobs/job.cxx b/framework/source/jobs/job.cxx
index a0488bc45aae..e0df5442e5af 100644
--- a/framework/source/jobs/job.cxx
+++ b/framework/source/jobs/job.cxx
@@ -94,7 +94,7 @@ Job::Job( /*IN*/ const css::uno::Reference< css::uno::XComponentContext >& xCont
/**
@short superfluous!
@descr Releasing of memory and reference must be done inside die() call.
- Otherwhise it's a bug.
+ Otherwise it's a bug.
*/
Job::~Job()
{
@@ -175,7 +175,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
css::uno::Sequence< css::beans::NamedValue > lJobArgs = impl_generateJobArgs(lDynamicArgs);
// It's necessary to hold us self alive!
// Otherwhise we might die by ref count ...
css::uno::Reference< css::task::XJobListener > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
try
@@ -274,7 +274,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
@descr It doesn't matter if this request is called from inside or
from outside. We release our internal structures and stop
every activity. After doing so - this instance will not be
- useable any longer! Of course we try to handle further requests
+ usable any longer! Of course we try to handle further requests
carefully. Maybe someone else holds a reference to us ...
*/
void Job::die()
@@ -663,7 +663,7 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& )
{
SolarMutexGuard g;
// Otherwhise try to close() it
css::uno::Reference< css::util::XCloseable > xClose(m_xJob, css::uno::UNO_QUERY);
if (xClose.is())
{
@@ -775,7 +775,7 @@ void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent ,
// No veto ...
// But don't call die() here or free our internal member.
// This must be done inside notifyClosing() only. Otherwhise the
// might stopped job has no chance to return its results or
// call us back. We must give him the chance to finish it's work successfully.
}
@@ -175,7 +175,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
css::uno::Sequence< css::beans::NamedValue > lJobArgs = impl_generateJobArgs(lDynamicArgs);
// It's necessary to hold us self alive!
- // Otherwhise we might die by ref count ...
+ // Otherwise we might die by ref count ...
css::uno::Reference< css::task::XJobListener > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
try
@@ -663,7 +663,7 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& )
{
SolarMutexGuard g;
- // Otherwhise try to close() it
+ // Otherwise try to close() it
css::uno::Reference< css::util::XCloseable > xClose(m_xJob, css::uno::UNO_QUERY);
if (xClose.is())
@@ -775,7 +775,7 @@ void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent ,
// No veto ...
// But don't call die() here or free our internal member.
- // This must be done inside notifyClosing() only. Otherwhise the
+ // This must be done inside notifyClosing() only. Otherwise the
// might stopped job has no chance to return its results or
// call us back. We must give him the chance to finish it's work successfully.